@@ -90,9 +90,9 @@ class StoreInterface(ABC):
         """Init the store, check the provided keys, and create possible client"""
         pass
 
-    def get_from_config(self, store: str, value: str, infos: dict, default="") -> str:
+    def get_from_config(self, store: str, value: str, infos: dict, default=None) -> str:
         if value not in infos and f"{EnvPrefix}_{store}_{value}" not in os.environ:
-            if not default:
+            if default is None:
                 raise Exception(
                     f"Config error: '{value}' is required in store '{store}'"
                     f" or {EnvPrefix}_{store}_{value} in env"
