@@ -93,6 +93,30 @@ def test_store_pass_secret_not_exists(config):
     ...
 
 
+@skip_unimplemented_test
+@with_tmp_conf
+def test_store_gcp_secret_exists(config):
+    ...
+
+
+@skip_unimplemented_test
+@with_tmp_conf
+def test_store_gcp_secret_not_exists(config):
+    ...
+
+
+@skip_unimplemented_test
+@with_tmp_conf
+def test_store_scaleway_secret_exists(config):
+    ...
+
+
+@skip_unimplemented_test
+@with_tmp_conf
+def test_store_scaleway_secret_not_exists(config):
+    ...
+
+
 @skip_unimplemented_test
 @with_tmp_conf
 def test_store_vault_secret_exists(config):
